@@ -1,4 +1,4 @@
-# $Id: windfinder.py 1218 2015-01-13 19:28:12Z mwall $
+# $Id: windfinder.py 1299 2015-04-14 10:50:54Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -12,7 +12,7 @@ http://www.windfinder.com/wind-cgi/httpload.pl?sender_id=<stationID>&password=<P
 
 Station must be registered first by visiting:
 
-http://www.windfinder.com/contact/contribute_weatherdata.htm
+http://www.windfinder.com/weather-station/add.htm
 
 The preferred upload frequency (post_interval) is one record every 15 minutes.
 
@@ -36,7 +36,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.6"
+VERSION = "0.7"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -151,10 +151,10 @@ class WindFinderThread(weewx.restx.RESTThread):
     def get_url(self, in_record):
         # put everything into the right units and scaling
         record = weewx.units.to_METRICWX(in_record)
-        if 'windspeed' in record and record['windspeed'] is not None:
-            record['windspeed'] = _mps_to_knot(record['windspeed'])
-        if 'gust' in record and record['gust'] is not None:
-            record['gust'] = _mps_to_knot(record['windspeed'])
+        if 'windSpeed' in record and record['windSpeed'] is not None:
+            record['windSpeed'] = _mps_to_knot(record['windSpeed'])
+        if 'windGust' in record and record['wingGust'] is not None:
+            record['windGust'] = _mps_to_knot(record['windGust'])
 
         # put data into expected structure and format
         values = {}
